#!/bin/sh

. ./build-env.sh

lxmmmkb=`echo ${lxdebkb} | cut -d '.' -f 1-2`

if [ ! -e linux-rockpro64-4.4.y ]; then
  #git clone -b rockpro64-4.4.y --depth 1 https://github.com/hardkernel/linux linux-rockpro64-4.4.y
  #git clone -b release-4.4 --depth 1 https://github.com/rockchip-linux/kernel linux-rockpro64-4.4.y
  #git clone -b rockpro64-4.4.y --depth 1 https://github.com/Owersun/linux-hardkernel linux-rockpro64-4.4.y
  #git clone -b release-4.4.202 --depth 1 https://github.com/ayufan-rock64/linux-kernel linux-rockpro64-4.4.y
  git clone -b rocksbc-4.4.y --depth 1 https://github.com/scpcom/linux-ayufan-4.4.y linux-rockpro64-4.4.y
fi

echo "Copying files from linux-${lxmmmkb}.y git..."
mkdir linux && \
cp -apP linux-rockpro64-4.4.y/. linux/

cd linux

VERSION=`cat Makefile | grep -E '^VERSION.=' | cut -d "=" -f 2- | tr -d " \t\n\r"`
PATCHLEVEL=`cat Makefile | grep PATCHLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`
SUBVERSION=`cat Makefile | grep SUBLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`

mkdir -p patches/platform

cp -apP ../patches/. patches/platform/
cat patches/platform/series-platform >> patches/series
quilt push -a

if [ -e patches/platform/series-rockchip ]; then
  mv patches/platform/rockchip patches/
  cat patches/platform/series-rockchip >> patches/series
  quilt push -a
fi

if [ -e patches/platform/series-rockchip ]; then
  cat patches/platform/series-rockchip-20190125 >> patches/series
  cat patches/platform/series-rockchip-20190220 >> patches/series
  cat patches/platform/series-rockchip-20190516 >> patches/series
  cat patches/platform/series-rockchip-20190617 >> patches/series
  cat patches/platform/series-rockchip-20190628 >> patches/series
  cat patches/platform/series-rockchip-20190927 >> patches/series
  cat patches/platform/series-rockchip-20191029 >> patches/series
  cat patches/platform/series-rockchip-20200120 >> patches/series
  cat patches/platform/series-rockchip-20200316 >> patches/series
  cat patches/platform/series-rockchip-99991231 >> patches/series

  mkdir -p patches/mainline
  for p in `cat patches/series | grep -v '^#' | grep patch` ; do
    if [ ! -e patches/${p} ]; then
      if [ -e ../patches/${p} ]; then
        cp -p ../patches/${p} patches/${p}
      else
        echo patches/${p}
      fi
    fi
  done

  quilt push -a
fi

if [ -e patches/platform/series-owersun ]; then
  mv patches/platform/owersun patches/
  cat patches/platform/series-owersun >> patches/series
  quilt push -a
fi

if [ -e patches/platform/series-radxa ]; then
  mv patches/platform/radxa patches/
  cat patches/platform/series-radxa >> patches/series
  quilt push -a
fi

if [ -e patches/platform/mainline ]; then
  mv patches/platform/mainline patches/
  for s in `ls patches/platform/series-mainline-???` ; do
    v=`basename $s | cut -d '-' -f 3`
    if [ $SUBVERSION -lt $v ]; then
      echo ""
      echo "" >> patches/series
      cat $s >> patches/series
      quilt push -a
    fi
  done
fi

# binary patches
git apply patches/rockchip/0550094bdb94e316c5f0b64b84a428c9f55f8cb0.patch
git apply patches/rockchip/9579567b7dbcc961a670ed6a9463b2b4bd60ceac.patch

pcount=`cat patches/series | grep -v -E '^#' | grep patch | wc -l`

echo "Applied ${pcount} patches."

for f in ../patches/*_defconfig ; do
  c=`basename $f`
  c=${c/_defconfig/}

  if grep -q '^CONFIG_ARM64=y' $f ; then
    if [ -e arch/arm64/configs/${c}_defconfig ]; then
     mv arch/arm64/configs/${c}_defconfig arch/arm64/configs/${c}_git_defconfig
    fi
    cp -p $f arch/arm64/configs/
  fi
done

tar xzf ../linux-4.4.y-*-firmware-edid.tar.gz

echo OK
